@@ -1,12 +1,12 @@
 import os
 import sys
-import psutil
 import requests
 import tarfile
 import tempfile
 import backstage
 from backstage.venue import use_venue
 from backstage.venue import Venue
+import time
 
 class Act():
     def __init__(self, venue, actname):
@@ -35,6 +35,9 @@ class Act():
         except IOError:
             print 'Could not update, permission denied.'
             return
+        time.sleep(2)
+        self.get_uwsgi_port()
+        return
 
 
 
